==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_main_calendar.js <==
_me = frm_main_calendar.prototype;
function frm_main_calendar(){};

_me.__constructor = function(sDataset)
{
	var me = this;
	this.__sDataset = sDataset;
	dataSet.obey(this,null,sDataset);
	
	this.calendar._onchange = function(aValues){
		me._onItemChange(1,aValues);
	};
	
	this.calendar._ondblclick = function(e,elm,arg)
	{
		switch (arg.evntype)
		{
			case 'event':
				var oRepeating = dataSet.get('items', [me.__aid, me.__fid, arg['id']]);
				Item.open([me.__aid, me.__fid, me._stripPipe(arg['id'])],oRepeating);
				break;

			case 'allday':
			case 'blank':
				if (!this.__rights.write) return;

				arg['enddate'] = arg['startdate'];

				if (arg['evntype'] == 'allday')
					arg['enddate']++;
					
				var nStartTime = (arg['starttime'] >= 0) ? arg['starttime']/60 : -1;
				var nEndTime = (arg['starttime'] >= 0) ? (arg['starttime']/60) + 30 : -1;
				var aInterval = {'EVNSTARTDATE':arg['startdate'],'EVNSTARTTIME':nStartTime,'EVNENDDATE':arg['enddate'],'EVNENDTIME':nEndTime};

				gui._create('gw',Mapping.getFormNameByGWType('E'),'','',me.__aid,me.__fid,'',aInterval);
				break;
		}
	};
	
	this.calendar._oncontext = function(e,elm,arg)
	{
		var cmenu = gui._create("cmenu", "obj_context_item");
		
		arg['aid'] = me.__aid;
		arg['fid'] = me.__fid;

		switch (arg['evntype'])
		{
			case 'allday':
			case 'blank':
				arg['enddate'] = arg['startdate'];

				if (arg['evntype'] == 'allday')
					arg['enddate']++;
				
				var nStartTime = (arg['starttime'] >= 0) ? arg['starttime']/60 : -1;
				var nEndTime = (arg['starttime'] >= 0) ? (arg['starttime']/60)+30 : -1;
				
				var rawDate = parseJulianDate(arg['startdate']); 
				var date = new Date(rawDate.year, rawDate.month-1, rawDate.day);

				cmenu._fill([
					{"title": 'POPUP_ITEMS::NEW', 'arg': [Item.createInFolder, [arg['aid'], arg['fid'], {
						'EVNSTARTDATE': arg['startdate'],
						'EVNSTARTTIME': nStartTime,
						'EVNENDDATE': arg['enddate'],
						'EVNENDTIME': nEndTime
					}]],'disabled':!this.__rights.write},
					{"title": '-'},
					{"title": 'MAIN_MENU::DAY_VIEW', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid,fid:me.__fid}, 'day_view', true, date]]},
	 				{"title": 'MAIN_MENU::WEEK_VIEW', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid, fid:me.__fid}, 'week_view', true, date]]},
		 			{"title": 'MAIN_MENU::MONTH_VIEW', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid, fid:me.__fid}, 'month_view', true, date]]},
					{"title": 'MAIN_MENU::EVENTS_LIST', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid, fid:me.__fid}, 'list_view', true]]}
				]);
				break;

			case 'selection':
				var nStartTime;

				if (arg['starttime'] >= 0)
					nStartTime = arg['starttime']/60;
				else{
					nStartTime = -1;
					arg['enddate']++;
				}

				var nEndTime = (arg['endtime'] >= 0) ? arg['endtime']/60 : -1;
				var aMenu = [{"title": 'POPUP_ITEMS::NEW', 'arg': [Item.createInFolder, [arg['aid'], arg['fid'], {
					'EVNSTARTDATE': arg['startdate'],
					'EVNSTARTTIME': nStartTime,
					'EVNENDDATE': arg['enddate'],
					'EVNENDTIME': nEndTime
				}]],'disabled':!this.__rights.write}];


				//DELETE SELECTION 1
				if (!Is.Empty(arg['contains'])) {
                    for(var i in arg['contains']){
						if (arg['contains'][i].indexOf('|')<0){
							aMenu.push({"title":'-'});
							aMenu.push({"title": 'POPUP_ITEMS::DELETE_SELECTED', 'arg': [Item.remove, [[arg['aid'], arg['fid'], arg['contains']]]],'disabled':!this.__rights.remove});
							break;
						}
					}
				}

				cmenu._fill(aMenu);
				break;

			case 'event':
				var origItem = me._stripPipe(arg['id']);
				var id = [arg['aid'], arg['fid'], origItem];
				var ids = [arg['aid'], arg['fid'], [origItem]];
				if (Item.hasReccurence([arg['aid'],arg['fid'],origItem]))
					var oRepeating = dataSet.get('items', [arg['aid'],arg['fid'],arg['id']]);

				cmenu._fill(obj_context_item.createGWMenu(id, ids, 'E', false, oRepeating, this.__rights));
				break;
		}
		cmenu._place(e.clientX,e.clientY);
	};
};


_me.__update = function()
{
	if (!Is.Defined(this.calendar)) return;
//	var aRange = this.calendar._range();

//	if (this.__aid == sAccId && this.__fid == sFolId && aRange['start'] == nStart && aRange['end'] == nEnd)
		this.__refresh();

/*
	this.__getFolder();

	var range = this.calendar._range();

	if (!Is.Defined(range['start']))
		return;

	var items = new wm_items;

	items.list({"aid":this.__aid,"fid":this.__fid,"values":['EVNSTARTDATE','EVNSTARTTIME','EVNENDDATE','EVNENDTIME','EVNTITLE','EVNCOLOR'],
		"filter":{'interval':range['start']+'-'+range['end']}},
		'event_view','','',[this,'__onServerResponse',[this.__aid,this.__fid,range['start'],range['end']]]);
*/
};

_me._serverSort = function()
{
	this.__getFolder();

	//set rights for calendar object
    this.calendar._rights(WMFolders.getAccess({'aid':this.__aid,'fid':this.__fid}));
    
	var range = this.calendar._range();

	if (!Is.Defined(range['start']))
		return;

	var items = new wm_items;

    var aValues = WMItems.default_values(this.__fid,'EI');
	items.list({"aid":this.__aid,"fid":this.__fid,"values":aValues,
		"filter":{'interval':range['start']+'-'+range['end']}},
		'items');
};

/*
	nEditType:
		0 .. edit only this instance
		1 .. edit all instances
		2 .. all folowing*
*/
_me._onItemChange = function(nEditType, aValues, bIgnoreRepeating) {

	var sAccId = this.__aid;
	var sFolId = this.__fid;
	var sItId = this._stripPipe(aValues['id']);

	var bRepeats = Item.hasReccurence([sAccId,sFolId,sItId]);
	if (bRepeats && !bIgnoreRepeating){
	
		// invoke dialog to confirm type of the repeating (only this item or all items) and callback this function again
		var cfm = gui._create('frm_confirm','frm_confirm_repeating', '','', [this, '_onItemChange', [aValues, true]],'REPEATING_CONFIRM::TITLE_EDIT','REPEATING_CONFIRM::TEXT_EDIT_2');
			var me = this;
			cfm._onclose = function(){
				me.__refresh();
				return true;
			};

		return;
	}

	var nStartTime = (aValues['starttime'] >= 0) ? aValues['starttime']/60 : -1;
	var nEndTime = (aValues['endtime'] >= 0) ? aValues['endtime']/60 : -1;

	var aResultValues = {'EVNSTARTTIME':nStartTime,'EVNENDTIME':nEndTime};

	switch(nEditType.toString()){
		//all following
		case '2':
			if (bRepeats)
				aResultValues['EXPFOLLOWING'] = 'true';

		//this instance
		case '0':
			if (bRepeats){
				var oRepeating = dataSet.get('items', [sAccId,sFolId,aValues['id']]);
				aResultValues['EXPDATE'] = oRepeating['EVNSTARTDATE'];
				aResultValues['EVNSTARTDATE'] = aValues['startdate'];
				aResultValues['EVNENDDATE'] = (nStartTime >= 0) ? aValues['enddate'] : aValues['enddate'] + 1;
				break;
			}
		//all
		default:

			/*
				Pokud se posouva instanci uvnitr opakovani <-->
				chova se to jako by se posouvalo 1. instanci opakovani
			*/

			if (!bRepeats || sItId==aValues['id']){
				aResultValues['EVNSTARTDATE'] = aValues['startdate'];
				aResultValues['EVNENDDATE'] = (nStartTime >= 0) ? aValues['enddate'] : aValues['enddate'] + 1;
			}
			else{
				var oRepeating1 = dataSet.get('items', [sAccId,sFolId,aValues['id']]);

				aResultValues['EVNSTARTDATE'] = parseInt(aValues.osd) + parseInt(aValues.startdate) - parseInt(oRepeating1.EVNSTARTDATE);
				aResultValues['EVNENDDATE'] = parseInt(aValues.oed) + parseInt(aValues.enddate) - parseInt(oRepeating1.EVNENDDATE);
/*
				var oRepeating0 = dataSet.get('items', [sAccId,sFolId,sItId]);
				aResultValues['EVNSTARTDATE'] = parseInt(oRepeating0.EVNSTARTDATE) + parseInt(aValues.startdate) - parseInt(oRepeating1.EVNSTARTDATE);
				aResultValues['EVNENDDATE'] = parseInt(oRepeating0.EVNENDDATE) + parseInt(aValues.enddate) - parseInt(oRepeating1.EVNENDDATE);
*/
			}
		}

		//Poslme update na server
		WMItems.add([sAccId, sFolId, sItId], {"values":aResultValues},'dummy','','',[this,'__addEventHandler',[sAccId,sFolId,bRepeats]]);
}

_me._stripPipe = function(s){
	var nIndex;
	if ((nIndex = s.indexOf('|')) >= 0)
		return s.substr(0,nIndex);
	else
		return s;
};

_me._createEvent = function()
{
	var aSelection = this.calendar._selection;

	if (!Is.Empty(aSelection)){
		var nStartTime;

		if (aSelection['starttime'] >= 0)
			nStartTime = aSelection['starttime']/60;
		else{
			nStartTime = -1;
			aSelection['enddate']++;
		}

		var nEndTime = (aSelection['endtime'] >= 0) ? aSelection['endtime']/60 : -1;
		var aInterval = {'EVNSTARTDATE':aSelection['startdate'],'EVNSTARTTIME':nStartTime,'EVNENDDATE':aSelection['enddate'],'EVNENDTIME':nEndTime};

		gui._create('gw', Mapping.getFormNameByGWType('E'),'','',this.__aid,this.__fid,'',aInterval);
	}
	else
		gui._create('gw',Mapping.getFormNameByGWType('E'),'','',this.__aid,this.__fid,'',getActualEventTime());
};

_me._getDate = function() {
	var aSelection = this.calendar._selection;
	if (aSelection && aSelection.startdate) {
		var date = new Date();
		    date.setQTime(aSelection.startdate);
		return date;
	}
	else
		return (this.__date) ? this.__date : new Date();
};


_me.__onServerResponse = function(sAccId,sFolId,nStart,nEnd)
{
	if (!Is.Defined(this.calendar)) return;
	var aRange = this.calendar._range();

	if (this.__aid == sAccId && this.__fid == sFolId && aRange['start'] == nStart && aRange['end'] == nEnd)
		this.__refresh();
};

_me.__refresh = function () {

	var aValues = dataSet.get('items')[this.__aid][this.__fid];

	var aFillData = [];
	var aColors = {
		'1': '#F58F9E', '2': '#9DCEE7', '3': '#C6F292', '4': '#D7D7D7',
		'5': '#FBB088', '6': '#9EE7E7', '7': '#E7B39E', '8': '#B296EE',
		'9': '#B9CEDC', 'A': '#FAE18A'
	};

	var sColor;
	for (var i in aValues)
	{
		if (aValues[i]['EVNSTARTTIME'] < 0)
			aValues[i]['EVNENDDATE']--;

		sColor = (Is.Defined(aValues[i]['EVNCOLOR']) && aColors[aValues[i]['EVNCOLOR']]) ? aColors[aValues[i]['EVNCOLOR']] : ''; 
		aFillData.push({'starttime':(aValues[i]['EVNSTARTTIME'] >= 0) ? aValues[i]['EVNSTARTTIME']*60 : -1,
						'endtime':(aValues[i]['EVNENDTIME'] >= 0) ? aValues[i]['EVNENDTIME']*60 : -1,
						'startdate':aValues[i]['EVNSTARTDATE'],
						'enddate':aValues[i]['EVNENDDATE'],
						'title':aValues[i]['EVNTITLE'],
						'osd':aValues[i]['OSD'],
						'oed':aValues[i]['OED'],
						'evnclass':aValues[i]['EVNCLASS'],
						'id':i,
						'color':sColor
						});
	}

	this.calendar._fill(aFillData);
};

_me.__addEventHandler = function(bOk,sAccId,sFolId,bRec){

	if (!bOk)
		this._update();

	if (bRec){
		this._serverSort();
	}
};

_me.__getStartDay = function(){
	storage.library('gw_others');
	var aCalendarSettings = (new gw_others).get('CALENDAR_SETTINGS','storage')['VALUES'];
	
	if (aCalendarSettings['begin_on_today'] != '0')
		return (new Date()).getDay();
	else if (Is.Defined(aCalendarSettings['week_begins'])) {
		var aDays = {'sunday':0,'monday':1,'tuesday':2,'wednesday':3,'thursday':4,'friday':5,'saturday':6};
		
		return aDays[aCalendarSettings['week_begins']];
	} else {
		return 0;
	}
};

_me.__getWorkingHours = function(){
	storage.library('gw_others');
	var oSettings = new gw_others;
	var sTime = {};
	sTime['start'] = oSettings.get('CALENDAR_SETTINGS','storage')['VALUES']['day_begins'];
	sTime['end'] = oSettings.get('CALENDAR_SETTINGS','storage')['VALUES']['day_ends'];
	if (typeof sTime['start'] == 'undefined')
		sTime['start'] = oSettings.getDefaultValues('CALENDAR_SETTINGS')['DAY_BEGINS'];
	if (typeof sTime['end'] == 'undefined')
		sTime['end'] = oSettings.getDefaultValues('CALENDAR_SETTINGS')['DAY_ENDS'];
	return sTime;
};

_me.__getFolder = function(){
	var aItems = dataSet.get(this.__sDataset);

	for (var sAccId in aItems)
		for (var sFolId in aItems[sAccId])
		{
			this.__aid = sAccId;
			this.__fid = sFolId;
			return;
		}

	var aActive = gui.frm_main.folders._getActive();
	this.__aid = aActive[0];
	this.__fid = aActive[1];
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_main_calendar.js <==
_me = frm_main_calendar.prototype;
function frm_main_calendar(){};

_me.__constructor = function(sDataset)
{
	var me = this;
	this.__sDataset = sDataset;
	dataSet.obey(this,null,sDataset);
	
	this.calendar._onchange = function(aValues){
		me._onItemChange(1,aValues);
	};
	
	this.calendar._ondblclick = function(e,elm,arg)
	{
		switch (arg.evntype)
		{
			case 'event':
				var oRepeating = dataSet.get('items', [me.__aid, me.__fid, arg['id']]);
				Item.open([me.__aid, me.__fid, me._stripPipe(arg['id'])],oRepeating);
				break;

			case 'allday':
			case 'blank':
				if (!this.__rights.write) return;

				arg['enddate'] = arg['startdate'];

				if (arg['evntype'] == 'allday')
					arg['enddate']++;
					
				var nStartTime = (arg['starttime'] >= 0) ? arg['starttime']/60 : -1;
				var nEndTime = (arg['starttime'] >= 0) ? (arg['starttime']/60) + 30 : -1;
				var aInterval = {'EVNSTARTDATE':arg['startdate'],'EVNSTARTTIME':nStartTime,'EVNENDDATE':arg['enddate'],'EVNENDTIME':nEndTime};

				gui._create('gw',Mapping.getFormNameByGWType('E'),'','',me.__aid,me.__fid,'',aInterval);
				break;
		}
	};
	
	this.calendar._oncontext = function(e,elm,arg)
	{
		var cmenu = gui._create("cmenu", "obj_context_item");
		
		arg['aid'] = me.__aid;
		arg['fid'] = me.__fid;

		switch (arg['evntype'])
		{
			case 'allday':
			case 'blank':
				arg['enddate'] = arg['startdate'];

				if (arg['evntype'] == 'allday')
					arg['enddate']++;
				
				var nStartTime = (arg['starttime'] >= 0) ? arg['starttime']/60 : -1;
				var nEndTime = (arg['starttime'] >= 0) ? (arg['starttime']/60)+30 : -1;
				
				var rawDate = parseJulianDate(arg['startdate']); 
				var date = new Date(rawDate.year, rawDate.month-1, rawDate.day);

				cmenu._fill([
					{"title": 'POPUP_ITEMS::NEW', 'arg': [Item.createInFolder, [arg['aid'], arg['fid'], {
						'EVNSTARTDATE': arg['startdate'],
						'EVNSTARTTIME': nStartTime,
						'EVNENDDATE': arg['enddate'],
						'EVNENDTIME': nEndTime
					}]],'disabled':!this.__rights.write},
					{"title": '-'},
					{"title": 'MAIN_MENU::DAY_VIEW', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid,fid:me.__fid}, 'day_view', true, date]]},
	 				{"title": 'MAIN_MENU::WEEK_VIEW', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid, fid:me.__fid}, 'week_view', true, date]]},
		 			{"title": 'MAIN_MENU::MONTH_VIEW', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid, fid:me.__fid}, 'month_view', true, date]]},
					{"title": 'MAIN_MENU::EVENTS_LIST', 'arg': [gui.frm_main, '_selectView', [{aid:me.__aid, fid:me.__fid}, 'list_view', true]]}
				]);
				break;

			case 'selection':
				var nStartTime;

				if (arg['starttime'] >= 0)
					nStartTime = arg['starttime']/60;
				else{
					nStartTime = -1;
					arg['enddate']++;
				}

				var nEndTime = (arg['endtime'] >= 0) ? arg['endtime']/60 : -1;
				var aMenu = [{"title": 'POPUP_ITEMS::NEW', 'arg': [Item.createInFolder, [arg['aid'], arg['fid'], {
					'EVNSTARTDATE': arg['startdate'],
					'EVNSTARTTIME': nStartTime,
					'EVNENDDATE': arg['enddate'],
					'EVNENDTIME': nEndTime
				}]],'disabled':!this.__rights.write}];


				//DELETE SELECTION 1
				if (!Is.Empty(arg['contains'])) {
                    for(var i in arg['contains']){
						if (arg['contains'][i].indexOf('|')<0){
							aMenu.push({"title":'-'});
							aMenu.push({"title": 'POPUP_ITEMS::DELETE_SELECTED', 'arg': [Item.remove, [[arg['aid'], arg['fid'], arg['contains']]]],'disabled':!this.__rights.remove});
							break;
						}
					}
				}

				cmenu._fill(aMenu);
				break;

			case 'event':
				var origItem = me._stripPipe(arg['id']);
				var id = [arg['aid'], arg['fid'], origItem];
				var ids = [arg['aid'], arg['fid'], [origItem]];
				if (Item.hasReccurence([arg['aid'],arg['fid'],origItem]))
					var oRepeating = dataSet.get('items', [arg['aid'],arg['fid'],arg['id']]);

				cmenu._fill(obj_context_item.createGWMenu(id, ids, 'E', false, oRepeating, this.__rights));
				break;
		}
		cmenu._place(e.clientX,e.clientY);
	};
};


_me.__update = function()
{
	if (!Is.Defined(this.calendar)) return;
//	var aRange = this.calendar._range();

//	if (this.__aid == sAccId && this.__fid == sFolId && aRange['start'] == nStart && aRange['end'] == nEnd)
		this.__refresh();

/*
	this.__getFolder();

	var range = this.calendar._range();

	if (!Is.Defined(range['start']))
		return;

	var items = new wm_items;

	items.list({"aid":this.__aid,"fid":this.__fid,"values":['EVNSTARTDATE','EVNSTARTTIME','EVNENDDATE','EVNENDTIME','EVNTITLE','EVNCOLOR'],
		"filter":{'interval':range['start']+'-'+range['end']}},
		'event_view','','',[this,'__onServerResponse',[this.__aid,this.__fid,range['start'],range['end']]]);
*/
};

_me._serverSort = function()
{
	this.__getFolder();

	//set rights for calendar object
    this.calendar._rights(WMFolders.getAccess({'aid':this.__aid,'fid':this.__fid}));
    
	var range = this.calendar._range();

	if (!Is.Defined(range['start']))
		return;

	var items = new wm_items;

    var aValues = WMItems.default_values('EI');
	items.list({"aid":this.__aid,"fid":this.__fid,"values":aValues,
		"filter":{'interval':range['start']+'-'+range['end']}},
		'items');
};

/*
	nEditType:
		0 .. edit only this instance
		1 .. edit all instances
		2 .. all folowing*
*/
_me._onItemChange = function(nEditType, aValues, bIgnoreRepeating) {

	var sAccId = this.__aid;
	var sFolId = this.__fid;
	var sItId = this._stripPipe(aValues['id']);

	var bRepeats = Item.hasReccurence([sAccId,sFolId,sItId]);
	if (bRepeats && !bIgnoreRepeating){
	
		// invoke dialog to confirm type of the repeating (only this item or all items) and callback this function again
		var cfm = gui._create('frm_confirm','frm_confirm_repeating', '','', [this, '_onItemChange', [aValues, true]],'REPEATING_CONFIRM::TITLE_EDIT','REPEATING_CONFIRM::TEXT_EDIT_2');
			var me = this;
			cfm._onclose = function(){
				me.__refresh();
				return true;
			};

		return;
	}

	var nStartTime = (aValues['starttime'] >= 0) ? aValues['starttime']/60 : -1;
	var nEndTime = (aValues['endtime'] >= 0) ? aValues['endtime']/60 : -1;

	var aResultValues = {'EVNSTARTTIME':nStartTime,'EVNENDTIME':nEndTime};

	switch(nEditType.toString()){
		//all following
		case '2':
			if (bRepeats)
				aResultValues['EXPFOLLOWING'] = 'true';

		//this instance
		case '0':
			if (bRepeats){
				var oRepeating = dataSet.get('items', [sAccId,sFolId,aValues['id']]);
				aResultValues['EXPDATE'] = oRepeating['EVNSTARTDATE'];
				aResultValues['EVNSTARTDATE'] = aValues['startdate'];
				aResultValues['EVNENDDATE'] = (nStartTime >= 0) ? aValues['enddate'] : aValues['enddate'] + 1;
				break;
			}
		//all
		default:

			/*
				Pokud se posouva instanci uvnitr opakovani <-->
				chova se to jako by se posouvalo 1. instanci opakovani
			*/

			if (!bRepeats || sItId==aValues['id']){
				aResultValues['EVNSTARTDATE'] = aValues['startdate'];
				aResultValues['EVNENDDATE'] = (nStartTime >= 0) ? aValues['enddate'] : aValues['enddate'] + 1;
			}
			else{
				var oRepeating1 = dataSet.get('items', [sAccId,sFolId,aValues['id']]);

				aResultValues['EVNSTARTDATE'] = parseInt(aValues.osd) + parseInt(aValues.startdate) - parseInt(oRepeating1.EVNSTARTDATE);
				aResultValues['EVNENDDATE'] = parseInt(aValues.oed) + parseInt(aValues.enddate) - parseInt(oRepeating1.EVNENDDATE);
/*
				var oRepeating0 = dataSet.get('items', [sAccId,sFolId,sItId]);
				aResultValues['EVNSTARTDATE'] = parseInt(oRepeating0.EVNSTARTDATE) + parseInt(aValues.startdate) - parseInt(oRepeating1.EVNSTARTDATE);
				aResultValues['EVNENDDATE'] = parseInt(oRepeating0.EVNENDDATE) + parseInt(aValues.enddate) - parseInt(oRepeating1.EVNENDDATE);
*/
			}
		}

		//Poslme update na server
		WMItems.add([sAccId, sFolId, sItId], {"values":aResultValues},'dummy','','',[this,'__addEventHandler',[sAccId,sFolId,bRepeats]]);
}

_me._stripPipe = function(s){
	var nIndex;
	if ((nIndex = s.indexOf('|')) >= 0)
		return s.substr(0,nIndex);
	else
		return s;
};

_me._createEvent = function()
{
	var aSelection = this.calendar._selection;

	if (!Is.Empty(aSelection)){
		var nStartTime;

		if (aSelection['starttime'] >= 0)
			nStartTime = aSelection['starttime']/60;
		else{
			nStartTime = -1;
			aSelection['enddate']++;
		}

		var nEndTime = (aSelection['endtime'] >= 0) ? aSelection['endtime']/60 : -1;
		var aInterval = {'EVNSTARTDATE':aSelection['startdate'],'EVNSTARTTIME':nStartTime,'EVNENDDATE':aSelection['enddate'],'EVNENDTIME':nEndTime};

		gui._create('gw', Mapping.getFormNameByGWType('E'),'','',this.__aid,this.__fid,'',aInterval);
	}
	else
		gui._create('gw',Mapping.getFormNameByGWType('E'),'','',this.__aid,this.__fid,'',getActualEventTime());
};

_me._getDate = function() {
	var aSelection = this.calendar._selection;
	if (aSelection && aSelection.startdate) {
		var date = new Date();
		    date.setQTime(aSelection.startdate);
		return date;
	}
	else
		return (this.__date) ? this.__date : new Date();
};


_me.__onServerResponse = function(sAccId,sFolId,nStart,nEnd)
{
	if (!Is.Defined(this.calendar)) return;
	var aRange = this.calendar._range();

	if (this.__aid == sAccId && this.__fid == sFolId && aRange['start'] == nStart && aRange['end'] == nEnd)
		this.__refresh();
};

_me.__refresh = function () {

	var aValues = dataSet.get('items')[this.__aid][this.__fid];

	var aFillData = [];
	var aColors = {
		'1': '#F58F9E', '2': '#9DCEE7', '3': '#C6F292', '4': '#D7D7D7',
		'5': '#FBB088', '6': '#9EE7E7', '7': '#E7B39E', '8': '#B296EE',
		'9': '#B9CEDC', 'A': '#FAE18A'
	};

	var sColor;
	for (var i in aValues)
	{
		if (i == '/' || i =='#' || i == '$') continue;

		if (aValues[i]['EVNSTARTTIME'] < 0)
			aValues[i]['EVNENDDATE']--;

		sColor = (Is.Defined(aValues[i]['EVNCOLOR']) && aColors[aValues[i]['EVNCOLOR']]) ? aColors[aValues[i]['EVNCOLOR']] : ''; 
		aFillData.push({'starttime':(aValues[i]['EVNSTARTTIME'] >= 0) ? aValues[i]['EVNSTARTTIME']*60 : -1,
						'endtime':(aValues[i]['EVNENDTIME'] >= 0) ? aValues[i]['EVNENDTIME']*60 : -1,
						'startdate':aValues[i]['EVNSTARTDATE'],
						'enddate':aValues[i]['EVNENDDATE'],
						'title':aValues[i]['EVNTITLE'],
						'osd':aValues[i]['OSD'],
						'oed':aValues[i]['OED'],
						'evnclass':aValues[i]['EVNCLASS'],
						'id':i,
						'color':sColor
						});
	}

	this.calendar._fill(aFillData);
};

_me.__addEventHandler = function(bOk,sAccId,sFolId,bRec){

	if (!bOk)
		this._update();

	if (bRec){
		this._serverSort();
	}
};

_me.__getStartDay = function(){
	storage.library('gw_others');
	var aCalendarSettings = (new gw_others).get('CALENDAR_SETTINGS','storage')['VALUES'];
	
	if (aCalendarSettings['begin_on_today'] != '0')
		return (new Date()).getDay();
	else if (Is.Defined(aCalendarSettings['week_begins'])) {
		var aDays = {'sunday':0,'monday':1,'tuesday':2,'wednesday':3,'thursday':4,'friday':5,'saturday':6};
		
		return aDays[aCalendarSettings['week_begins']];
	} else {
		return 0;
	}
};

_me.__getWorkingHours = function(){
	storage.library('gw_others');

	//var oSettings = new gw_others;

	var sTime = {};
		sTime['start'] = GWOthers.getItem('CALENDAR_SETTINGS','day_begins');
		sTime['end'] = GWOthers.getItem('CALENDAR_SETTINGS','day_ends');
/*
	sTime['start'] = GWOthers.get('CALENDAR_SETTINGS','storage')['VALUES']['day_begins'];
	sTime['end'] = GWOthers.get('CALENDAR_SETTINGS','storage')['VALUES']['day_ends'];

	
	if (typeof sTime['start'] == 'undefined')
		sTime['start'] = GWOthers.getDefaultValues('CALENDAR_SETTINGS')['DAY_BEGINS'];
	if (typeof sTime['end'] == 'undefined')
		sTime['end'] = GWOthers.getDefaultValues('CALENDAR_SETTINGS')['DAY_ENDS'];
*/
	return sTime;
};

_me.__getFolder = function(){
	var aItems = dataSet.get(this.__sDataset);

	for (var sAccId in aItems)
		for (var sFolId in aItems[sAccId])
		{
			this.__aid = sAccId;
			this.__fid = sFolId;
			return;
		}

	var aActive = gui.frm_main.folders._getActive();
	this.__aid = aActive[0];
	this.__fid = aActive[1];
};
